from setuptools import setup

setup(
   name='weather-metrics',
   version='66.0.0',
   author='Yandex',
   author_email='security@yandex-team.ru',
   url='https://ya.ru',
   readme="README.md",
   long_description="""This is a security placeholder package.
If you want to claim this name for legitimate purposes,
please contact us at secuirty@yandex-team.ru or pypi-security@yandex-team.ru""",
   long_description_content_type='text/markdown',
   description='A package to prevent Dependency Confusion attacks against Yandex.',
   )
